@@ -6,7 +6,7 @@ async fn main_async() {
     let scale = Box::new(2usize);
     let addition = Box::new(1usize);
 
-    let doubled = futures::stream::iter(0..1000)
+    let doubled: Vec<_> = futures::stream::iter(0..1000)
         // parallel tasks on futures
         .par_then(None, move |value| {
             // cloned needed variables in the main thread
@@ -24,7 +24,7 @@ async fn main_async() {
             move || value + cloned
         })
         // call `collect()` from futures crate
-        .collect::<Vec<_>>()
+        .collect()
         .await;
 
     // the output will be ordered
@@ -32,14 +32,19 @@ async fn main_async() {
     assert_eq!(doubled, expect);
 }
 
-#[cfg(feature = "runtime_async-std")]
+#[cfg(feature = "runtime-async-std")]
 #[async_std::main]
 async fn main() {
     main_async().await
 }
 
-#[cfg(feature = "runtime_tokio")]
+#[cfg(feature = "runtime-tokio")]
 #[tokio::main]
 async fn main() {
     main_async().await
 }
+
+#[cfg(feature = "runtime-smol")]
+fn main() {
+    smol::block_on(main_async())
+}
